@@ -1,15 +1,15 @@
 ##########################################################################
 # haufe.testrunner
 #
-# (C) 2007, Haufe Mediengruppe
+# (C) 2007, 2008 Haufe Mediengruppe
 ##########################################################################
 
 
 import os
 import sys
 import re
-import subprocess
 import smtplib
+import shutil
 import tempfile
 import time
 from datetime import datetime
@@ -134,8 +134,6 @@ def testrunner(options, args):
 
         from email.MIMEMultipart import MIMEMultipart
         from email.MIMEText import MIMEText
-        from email.MIMEImage import MIMEImage
-        from email.Header import Header
 
         outer = MIMEMultipart()
         outer['From'] = 'ep-testrunner-no-reply@haufe.de'
