@@ -1,7 +1,7 @@
 ################################################################
 # haufe.testrunner
 #
-# (C) 2007, Haufe Mediengruppe
+# (C) 2007, 2008 Haufe Mediengruppe
 ################################################################
 
 """
@@ -14,13 +14,13 @@ from optparse import OptionParser
 from model import getModel
 from config import WRAPPER_NAME
 from setup import setup
-
+from sqlalchemy.orm import create_session
 
 
 def createTables(option, opt_str, value, parser):
     """ create the media database """
 
-    Base, mappers = getModel(engine)    
+    Base, mappers = getModel(engine)
     Base.metadata.create_all()
 
 
@@ -28,7 +28,7 @@ def createDatabase(option, opt_str, value, parser):
     """ low-level database creation """                
 
     url = engine.url
- 
+
     cmd = 'dropdb --username %s --host %s %s' % (url.username, url.host, url.database) 
     os.system(cmd)
 
@@ -36,6 +36,24 @@ def createDatabase(option, opt_str, value, parser):
     os.system(cmd)
 
 
+
+def deleteTestrunner(option, opt_str, value, parser):
+    """ Remove a testrunner by id including its associated 
+        and results.
+    """
+
+    Base, mappers = getModel(engine)
+    TR = mappers[0]
+    session = create_session(engine)
+    for tr in session.query(TR).filter_by(id=value):
+        for run in tr.run:
+            for result in run.result:
+                session.delete(result)
+            session.delete(run)
+        session.delete(tr)
+    session.flush()
+    print 'Testrunner deleted'
+
 def main():
 
     global engine
@@ -50,8 +68,10 @@ def main():
                       help='(Re)create database')
     parser.add_option('-t', '--create-tables', action='callback', callback=createTables,
                       help='Create tables')
+    parser.add_option('-x', '--delete-testrunner', action='callback', default=None, callback=deleteTestrunner,
+                      type='int', help='Delete a testrunner by id')
 
-    options, args = parser.parse_args()    
+    options, args = parser.parse_args()
 
 
 if __name__ == '__main__':
